pub enum BoundedGraphError<Ix: IndexType = DefaultIx> {
EdgeRejected {
source: NodeIndex<Ix>,
target: NodeIndex<Ix>,
source_rejected: bool,
target_rejected: bool,
},
NodeNotFound {
source: Option<NodeIndex<Ix>>,
target: Option<NodeIndex<Ix>>,
},
}Expand description
Error type for bounded graph operations.
Variants
EdgeRejected
One or both nodes rejected the edge.
The node indices indicate which nodes were involved in the rejection.
If source_rejected is true, the source node rejected adding the outgoing edge.
If target_rejected is true, the target node rejected adding the incoming edge.
NodeNotFound
One or both nodes do not exist in the graph.
source is Some if the source node doesn’t exist.
target is Some if the target node doesn’t exist.
Implementations
Sourceimpl<Ix: IndexType> BoundedGraphError<Ix>
impl<Ix: IndexType> BoundedGraphError<Ix>
Sourcepub fn source_rejected(source: NodeIndex<Ix>, target: NodeIndex<Ix>) -> Self
pub fn source_rejected(source: NodeIndex<Ix>, target: NodeIndex<Ix>) -> Self
Creates an error indicating the source node rejected the edge.
Sourcepub fn target_rejected(source: NodeIndex<Ix>, target: NodeIndex<Ix>) -> Self
pub fn target_rejected(source: NodeIndex<Ix>, target: NodeIndex<Ix>) -> Self
Creates an error indicating the target node rejected the edge.
Sourcepub fn both_rejected(source: NodeIndex<Ix>, target: NodeIndex<Ix>) -> Self
pub fn both_rejected(source: NodeIndex<Ix>, target: NodeIndex<Ix>) -> Self
Creates an error indicating both nodes rejected the edge.