SimpleEdgeBounds

Trait SimpleEdgeBounds 

pub trait SimpleEdgeBounds { }
Marker trait indicating that a node uses simple edge count logic.

Types implementing both this trait and EdgeBounds automatically get a BoundedNode implementation that only checks edge counts, without considering properties of the other node.

This is useful for the common case where nodes have fixed edge limits that don’t depend on what they’re connecting to.

Implementors

Source

impl<const MAX_IN: usize, const MAX_OUT: usize, T> SimpleEdgeBounds for FixedEdgeCount<MAX_IN, MAX_OUT, T>